@@ -12,15 +12,23 @@ import java.util.ArrayList;
 import java.util.List;
 
 import org.gnu.glib.Boxed;
+import org.gnu.glib.Handle;
 
+/**
+ * Represents a dynamically-typed value in GConf.  
+ */
 public class ConfValue extends Boxed {
 	
+	/**
+	 * Construct a new ConfValue object of the type provided.
+	 * @param type
+	 */
 	public ConfValue(ConfValueType type) {
-		handle = gconf_value_new(type.getValue());
+		super(gconf_value_new(type.getValue()));
 	}
 	
-	public ConfValue(int handle) {
-		this.handle = handle;
+	public ConfValue(Handle handle) {
+		super(handle);
 	}
 
 	/* (non-Javadoc)
@@ -119,32 +127,26 @@ public class ConfValue extends Boxed {
 		return gconf_value_to_string(handle);
 	}
 	
-	/****************************************
-	 * BEGINNING OF NATIVE CODE
-	 ****************************************/
-	native static final protected int gconf_value_new(int type);
-	native static final protected int gconf_value_copy(int source);
-	native static final protected void gconf_value_free(int value);
-	native static final protected String gconf_value_get_string(int value);
-	native static final protected int gconf_value_get_int(int value);
-	native static final protected double gconf_value_get_float(int value);
-	native static final protected int gconf_value_get_list_type(int value);
-	native static final protected Object[] gconf_value_get_list(int value);
-	native static final protected int gconf_value_get_car(int value);
-	native static final protected int gconf_value_get_cdr(int value);
-	native static final protected boolean gconf_value_get_bool(int value);
-	native static final protected int gconf_value_get_schema(int value);
-	native static final protected void gconf_value_set_int(int value, int theInt);
-	native static final protected void gconf_value_set_string(int value, String theString);
-	native static final protected void gconf_value_set_bool(int value, boolean theBool);
-	native static final protected void gconf_value_set_float(int value, double theFloat);
-	native static final protected void gconf_value_set_schema(int value, int theSchema);
-	native static final protected void gconf_value_set_car(int value, int theCar);
-	native static final protected void gconf_value_set_cdr(int value, int theCdr);
-	native static final protected void gconf_value_set_list_type(int value, int type);
-	native static final protected void gconf_value_set_list(int value, Object[] theList);
-	native static final protected String gconf_value_to_string(int value);
-	/****************************************
-	 * END OF NATIVE CODE
-	 ****************************************/
+	native static final protected Handle gconf_value_new(int type);
+	native static final protected Handle gconf_value_copy(Handle source);
+	native static final protected void gconf_value_free(Handle value);
+	native static final protected String gconf_value_get_string(Handle value);
+	native static final protected int gconf_value_get_int(Handle value);
+	native static final protected double gconf_value_get_float(Handle value);
+	native static final protected int gconf_value_get_list_type(Handle value);
+	native static final protected Object[] gconf_value_get_list(Handle value);
+	native static final protected Handle gconf_value_get_car(Handle value);
+	native static final protected Handle gconf_value_get_cdr(Handle value);
+	native static final protected boolean gconf_value_get_bool(Handle value);
+	native static final protected Handle gconf_value_get_schema(Handle value);
+	native static final protected void gconf_value_set_int(Handle value, int theInt);
+	native static final protected void gconf_value_set_string(Handle value, String theString);
+	native static final protected void gconf_value_set_bool(Handle value, boolean theBool);
+	native static final protected void gconf_value_set_float(Handle value, double theFloat);
+	native static final protected void gconf_value_set_schema(Handle value, Handle theSchema);
+	native static final protected void gconf_value_set_car(Handle value, Handle theCar);
+	native static final protected void gconf_value_set_cdr(Handle value, Handle theCdr);
+	native static final protected void gconf_value_set_list_type(Handle value, int type);
+	native static final protected void gconf_value_set_list(Handle value, Object[] theList);
+	native static final protected String gconf_value_to_string(Handle value);
 }
