@@ -9,7 +9,7 @@
 
 #include <jni.h>
 #include <gconf/gconf.h>
-#include "jg_jnu.h"
+#include <libgtk-java/jg_jnu.h>
 
 #ifndef _Included_org_gnu_gconf_ConfMetaInfo
 #define _Included_org_gnu_gconf_ConfMetaInfo
